---
slug: 2-1
title: Remotion 2.1
author: Jonny Burger
author_title: Indie Hacker
author_url: https://github.com/JonnyBurger
author_image_url: https://avatars2.githubusercontent.com/u/1629785?s=460&u=12eb94da6070d00fc924761ce06e3a428d01b7e9&v=4
---

import { PlayerExample } from "../components/Player.tsx";
import { ExperimentalBadge } from "../components/Experimental.tsx";

This releases features new utility functions, improved developer experience and an experimental release of the Remotion Player!

## New `interpolateColors()` function 🌈

Now you can easily animate between colors and mix colors to create interesting animations using [`interpolateColors()`](/docs/interpolate-colors).

I personally used it to recreate [Apple's 'Spring Loaded' logo in Remotion](https://github.com/jonnyburger/spring-loaded) using only `<div>` elements.

<img src="https://github.com/JonnyBurger/spring-loaded/raw/main/out.gif" />

Thanks for [Shankhadeep Dey](https://github.com/Iamshankhadeep) for implementing this feature!

## New `measureSpring()` function 🌀

One problem when using a spring animation for transitions
is that you don't know the duration of the animation. This is why we added a new [`measureSpring()`](/docs/measure-spring) function!

Now you can adjust your timings in Remotion dynamically when changing spring configurations.

Thanks to [Samuel Rodriguez-Lozano](https://github.com/samuel3105) for implementing this feature!

## Documentation and developer experience updates

We invested time in making sure that if something goes wrong, you don't get stuck. Here are some things we did to improve your experience with Remotion:

- If you encounter a timeout, you will now see a stacktrace of where the `delayRender()` handle was not cleared. We also now have a [troubleshooting page for timeouts](/docs/timeout) and link to the documentation if you encounter the error.
- If you use Chromium and import an MP4 video, you get a more helpful error and we link to a [help page](/docs/media-playback-error).
- We added a guide for improving [performance](/docs/performance) while development and while rendering.
- The server-side rendering APIs [`bundle()`](/docs/bundle), [`getCompositions()`](/docs/get-compositions), [`renderFrames()`](/docs/render-frames) and [`stitchFramesToVideo()`](/docs/stitch-frames-to-video) with all their parameters are now more properly documented.
- If an exception is thrown while rendering, the log output in the console is now better.

## Alpha release of `@remotion/player`

<ExperimentalBadge/>

We are working on a Remotion player component that you can import into your React app. Today we are prereleasing the player for those who wish to experiment and provide us with feedback. Let us know what you think!

[**Read the documentation for `@remotion/player`**](/docs/player)
<PlayerExample />

## Test coverage updates

We now have over 450 tests, and the Remotion core has a test coverage of over 80% now. Thanks to Tobias Boner, Calvin Falter and Jonas Brunner for continuining their massive testign initiative!

We now also test across different node versions (12, 14 and 16), npm versions (v6 and v7) and FFMPEG versions (4.1 and 4.4) in addition to testing on 3 different operating systems so we can confidently release new features quickly.

For contributors, we now have a [TESTING.md](https://github.com/JonnyBurger/remotion/blob/main/TESTING.md) file.

## Miscellaneous

- You can now press <kbd>Shift+Right Arrow</kbd> to jump 1 second forward in the timeline and <kbd>Shift+Left Arrow</kbd> to jump 1 second back.
- `npm init video` will now setup a Remotion project with NPM, `yarn create video` will setup a project with Yarn.
- Node 16 and NPM 7 is now better supported, no warnings will be shown during installation and execution.
- Fixed several audio rendering issues: [#292](https://github.com/JonnyBurger/remotion/issues/292 [#293](https://github.com/JonnyBurger/remotion/issues/293) [#320](https://github.com/JonnyBurger/remotion/issues/320)
- When the update banner appears in the editor, you can now click to copy the command.
- You can now pass a React `ref` to `<Audio/>` and `<Video />` tags.
- We revamped the CLI output! How do you like it?
- The preview size option in the editor is now persisted, thanks [Oluwatobiju Judah](https://github.com/Tobijudah)!
- In the editor, the transparency toggle is now enabled by default.
